@@ -25,6 +25,7 @@
  * Boston, MA 02110-1301 USA.
  *
  * Copyright (C) 2012-2019 Aleksander Morgado <aleksander@aleksander.es>
+ * Copyright (c) 2022 Qualcomm Innovation Center, Inc.
  */
 
 #include <glib.h>
@@ -58,6 +59,8 @@
 #include "qmi-gms.h"
 #include "qmi-dsd.h"
 #include "qmi-sar.h"
+#include "qmi-dpm.h"
+#include "qmi-fox.h"
 
 #define PACKED __attribute__((packed))
 
@@ -1713,6 +1716,16 @@ qmi_message_get_printable_full (QmiMessage        *self,
     case QMI_SERVICE_DSD:
 #if defined HAVE_QMI_SERVICE_DSD
         contents = __qmi_message_dsd_get_printable (self, context, line_prefix);
+#endif
+        break;
+    case QMI_SERVICE_DPM:
+#if defined HAVE_QMI_SERVICE_DPM
+        contents = __qmi_message_dpm_get_printable (self, context, line_prefix);
+#endif
+        break;
+    case QMI_SERVICE_FOX:
+#if defined HAVE_QMI_SERVICE_FOX
+        contents = __qmi_message_fox_get_printable (self, context, line_prefix);
 #endif
         break;
 
@@ -1821,6 +1834,7 @@ __qmi_message_is_abortable (QmiMessage        *self,
     case QMI_SERVICE_IMSRTP:
     case QMI_SERVICE_RFRPE:
     case QMI_SERVICE_SSCTL:
+    case QMI_SERVICE_DPM:
     case QMI_SERVICE_CAT:
     case QMI_SERVICE_RMS:
     case QMI_SERVICE_FOTA:
@@ -1829,6 +1843,7 @@ __qmi_message_is_abortable (QmiMessage        *self,
     case QMI_SERVICE_PDC:
     case QMI_SERVICE_DSD:
     case QMI_SERVICE_QOS:
+    case QMI_SERVICE_FOX:
     default:
         return FALSE;
     }
