@@ -45,7 +45,6 @@ G_BEGIN_DECLS
 
 /**
  * SECTION:qmi-message
- * @title: QmiMessage
  * @short_description: Generic QMI message handling routines
  *
  * #QmiMessage is a generic type representing a QMI message of any kind
@@ -73,15 +72,6 @@ G_BEGIN_DECLS
  */
 typedef GByteArray QmiMessage;
 
-/**
- * QMI_MESSAGE_VENDOR_GENERIC:
- *
- * Generic vendor id (0x0000).
- *
- * Since: 1.18
- */
-#define QMI_MESSAGE_VENDOR_GENERIC 0x0000
-
 /*****************************************************************************/
 /* QMI Message life cycle */
 
@@ -164,7 +154,7 @@ QmiMessage *qmi_message_response_new (QmiMessage       *request,
  *
  * Atomically increments the reference count of @self by one.
  *
- * Returns: (transfer full) the new reference to @self.
+ * Returns: (transfer full): the new reference to @self.
  *
  * Since: 1.0
  */
@@ -180,6 +170,7 @@ QmiMessage *qmi_message_ref (QmiMessage *self);
  * Since: 1.0
  */
 void qmi_message_unref (QmiMessage *self);
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (QmiMessage, qmi_message_unref)
 
 /*****************************************************************************/
 /* QMI Message content getters */
@@ -313,32 +304,6 @@ const guint8 *qmi_message_get_data (QmiMessage  *self,
                                     gsize       *length,
                                     GError     **error);
 
-/*****************************************************************************/
-/* Version support from the database */
-/**
- * qmi_message_get_version_introduced_full:
- * @self: a #QmiMessage.
- * @context: a #QmiMessageContext.
- * @major: (out) return location for the major version.
- * @minor: (out) return location for the minor version.
- *
- * Gets, if known, the service version in which the given message was first
- * introduced.
- *
- * The lookup of the version may be specific to the @context provided, e.g. for
- * vendor-specific messages.
- *
- * If no @context given, the behavior is the same as qmi_message_get_version_introduced().
- *
- * Returns: %TRUE if @major and @minor are set, %FALSE otherwise.
- *
- * Since: 1.18
- */
-gboolean qmi_message_get_version_introduced_full (QmiMessage        *self,
-                                                  QmiMessageContext *context,
-                                                  guint             *major,
-                                                  guint             *minor);
-
 /*****************************************************************************/
 /* TLV builder & writer */
 
@@ -602,7 +567,7 @@ gboolean qmi_message_tlv_write_string (QmiMessage   *self,
  * qmi_message_tlv_read_init:
  * @self: a #QmiMessage.
  * @type: specific ID of the TLV to read.
- * @out_tlv_length: optional return location for the TLV size.
+ * @out_tlv_length: (out): optional return location for the TLV size.
  * @error: return location for error or %NULL.
  *
  * Starts reading a given TLV from the #QmiMessage.
@@ -620,8 +585,8 @@ gsize qmi_message_tlv_read_init (QmiMessage  *self,
  * qmi_message_tlv_read_guint8:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of the offset within the TLV value.
- * @out: return location for the read #guint8.
+ * @offset: (inout): address of the offset within the TLV value.
+ * @out: (out): return location for the read #guint8.
  * @error: return location for error or %NULL.
  *
  * Reads an unsigned byte from the TLV.
@@ -644,8 +609,8 @@ gboolean qmi_message_tlv_read_guint8 (QmiMessage  *self,
  * qmi_message_tlv_read_gint8:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
- * @out: return location for the read #gint8.
+ * @offset: (inout): address of a the offset within the TLV value.
+ * @out: (out): return location for the read #gint8.
  * @error: return location for error or %NULL.
  *
  * Reads a signed byte from the TLV.
@@ -668,9 +633,9 @@ gboolean qmi_message_tlv_read_gint8 (QmiMessage  *self,
  * qmi_message_tlv_read_guint16:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @endian: source endianness, which will be swapped to host byte order if necessary.
- * @out: return location for the read #guint16.
+ * @out: (out): return location for the read #guint16.
  * @error: return location for error or %NULL.
  *
  * Reads an unsigned 16-bit integer from the TLV, in host byte order.
@@ -694,9 +659,9 @@ gboolean qmi_message_tlv_read_guint16 (QmiMessage  *self,
  * qmi_message_tlv_read_gint16:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @endian: source endianness, which will be swapped to host byte order if necessary.
- * @out: return location for the read #gint16.
+ * @out: (out): return location for the read #gint16.
  * @error: return location for error or %NULL.
  *
  * Reads a signed 16-bit integer from the TLV, in host byte order.
@@ -720,9 +685,9 @@ gboolean qmi_message_tlv_read_gint16 (QmiMessage  *self,
  * qmi_message_tlv_read_guint32:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @endian: source endianness, which will be swapped to host byte order if necessary.
- * @out: return location for the read #guint32.
+ * @out: (out): return location for the read #guint32.
  * @error: return location for error or %NULL.
  *
  * Reads an unsigned 32-bit integer from the TLV, in host byte order.
@@ -746,9 +711,9 @@ gboolean qmi_message_tlv_read_guint32 (QmiMessage  *self,
  * qmi_message_tlv_read_gint32:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @endian: source endianness, which will be swapped to host byte order if necessary.
- * @out: return location for the read #gint32.
+ * @out: (out): return location for the read #gint32.
  * @error: return location for error or %NULL.
  *
  * Reads a signed 32-bit integer from the TLV, in host byte order.
@@ -772,9 +737,9 @@ gboolean qmi_message_tlv_read_gint32 (QmiMessage  *self,
  * qmi_message_tlv_read_guint64:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @endian: source endianness, which will be swapped to host byte order if necessary.
- * @out: return location for the read #guint64.
+ * @out: (out): return location for the read #guint64.
  * @error: return location for error or %NULL.
  *
  * Reads an unsigned 64-bit integer from the TLV, in host byte order.
@@ -798,9 +763,9 @@ gboolean qmi_message_tlv_read_guint64 (QmiMessage  *self,
  * qmi_message_tlv_read_gint64:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @endian: source endianness, which will be swapped to host byte order if necessary.
- * @out: return location for the read #gint64.
+ * @out: (out): return location for the read #gint64.
  * @error: return location for error or %NULL.
  *
  * Reads a signed 64-bit integer from the TLV, in host byte order.
@@ -824,10 +789,10 @@ gboolean qmi_message_tlv_read_gint64 (QmiMessage  *self,
  * qmi_message_tlv_read_sized_guint:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @n_bytes: number of bytes to read.
  * @endian: source endianness, which will be swapped to host byte order if necessary.
- * @out: return location for the read #guint64.
+ * @out: (out): return location for the read #guint64.
  * @error: return location for error or %NULL.
  *
  * Reads a @b_bytes-sized integer from the TLV, in host byte order.
@@ -852,9 +817,9 @@ gboolean qmi_message_tlv_read_sized_guint (QmiMessage  *self,
  * qmi_message_tlv_read_gfloat_endian:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @endian: source endianness, which will be swapped to host byte order if necessary.
- * @out: return location for the read #gfloat.
+ * @out: (out): return location for the read #gfloat.
  * @error: return location for error or %NULL.
  *
  * Reads a 32-bit floating-point number from the TLV.
@@ -878,9 +843,9 @@ gboolean qmi_message_tlv_read_gfloat_endian (QmiMessage  *self,
  * qmi_message_tlv_read_gdouble:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @endian: source endianness, which will be swapped to host byte order if necessary.
- * @out: return location for the read #gdouble.
+ * @out: (out): return location for the read #gdouble.
  * @error: return location for error or %NULL.
  *
  * Reads a 64-bit floating-point number from the TLV.
@@ -904,10 +869,10 @@ gboolean qmi_message_tlv_read_gdouble (QmiMessage  *self,
  * qmi_message_tlv_read_string:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @n_size_prefix_bytes: number of bytes used in the size prefix.
  * @max_size: maximum number of bytes to read, or 0 to read all available bytes.
- * @out: return location for the read string. The returned value should be freed with g_free().
+ * @out: (out): return location for the read string. The returned value should be freed with g_free().
  * @error: return location for error or %NULL.
  *
  * Reads a string from the TLV.
@@ -937,9 +902,9 @@ gboolean qmi_message_tlv_read_string (QmiMessage  *self,
  * qmi_message_tlv_read_fixed_size_string:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
- * @offset: address of a the offset within the TLV value.
+ * @offset: (inout): address of a the offset within the TLV value.
  * @string_length: amount of bytes to read.
- * @out: buffer preallocated by the client, with at least @string_length bytes.
+ * @out: (out): buffer preallocated by the client, with at least @string_length bytes.
  * @error: return location for error or %NULL.
  *
  * Reads a string from the TLV.
@@ -953,9 +918,9 @@ gboolean qmi_message_tlv_read_string (QmiMessage  *self,
  * Since 1.24.6 the read string is guaranteed to be valid UTF-8.
  *
  * The fixed sized field may be suffixed with e.g. 0xFF if the contents are
- * shorter than @string_length. Since 1.24.12, this method will return the
- * valid UTF-8 characters in the start of the string, instead of returning an
- * error when doing the full UTF-8 string validation.
+ * shorter than @string_length. Since 1.26, this method will return the valid
+ * UTF-8 characters in the start of the string, instead of returning an error
+ * when doing the full UTF-8 string validation.
  *
  * Returns: %TRUE if the variable is successfully read, otherwise %FALSE is returned and @error is set.
  *
@@ -970,9 +935,9 @@ gboolean qmi_message_tlv_read_fixed_size_string (QmiMessage  *self,
 
 #if defined (LIBQMI_GLIB_COMPILATION)
 G_GNUC_INTERNAL
-guint16 __qmi_message_tlv_read_remaining_size (QmiMessage  *self,
-                                               gsize        tlv_offset,
-                                               gsize        offset);
+guint16 qmi_message_tlv_read_remaining_size (QmiMessage  *self,
+                                             gsize        tlv_offset,
+                                             gsize        offset);
 #endif
 
 /*****************************************************************************/
@@ -998,8 +963,8 @@ typedef void (* QmiMessageForeachRawTlvFn) (guint8        type,
 /**
  * qmi_message_foreach_raw_tlv:
  * @self: a #QmiMessage.
- * @func: the function to call for each TLV.
- * @user_data: user data to pass to the function.
+ * @func: (scope call): the function to call for each TLV.
+ * @user_data: (closure func): user data to pass to the function.
  *
  * Calls the given function for each TLV found within the #QmiMessage.
  *
