@@ -80,21 +80,16 @@ quit_cb (gpointer user_data)
 }
 
 static void
-log_handler (const gchar *log_domain,
-             GLogLevelFlags log_level,
-             const gchar *message,
-             gpointer user_data)
+log_handler (const gchar    *log_domain,
+             GLogLevelFlags  log_level,
+             const gchar    *message,
+             gpointer        user_data)
 {
     const gchar *log_level_str;
-    time_t now;
-    gchar time_str[64];
-    struct tm *local_time;
-    gboolean err;
-
-    now = time ((time_t *) NULL);
-    local_time = localtime (&now);
-    strftime (time_str, 64, "%d %b %Y, %H:%M:%S", local_time);
-    err = FALSE;
+    time_t       now;
+    gchar        time_str[64];
+    struct tm   *local_time;
+    gboolean     err = FALSE;
 
     switch (log_level) {
     case G_LOG_LEVEL_WARNING:
@@ -127,6 +122,10 @@ log_handler (const gchar *log_domain,
     if (!verbose_flag && !err)
         return;
 
+    now = time ((time_t *) NULL);
+    local_time = localtime (&now);
+    strftime (time_str, 64, "%d %b %Y, %H:%M:%S", local_time);
+
     g_fprintf (err ? stderr : stdout,
                "[%s] %s %s\n",
                time_str,
@@ -139,7 +138,7 @@ print_version_and_exit (void)
 {
     g_print ("\n"
              PROGRAM_NAME " " PROGRAM_VERSION "\n"
-             "Copyright (2013-2021) Aleksander Morgado\n"
+             "Copyright (2013-2022) Aleksander Morgado\n"
              "License GPLv2+: GNU GPL version 2 or later <http://gnu.org/licenses/gpl-2.0.html>\n"
              "This is free software: you are free to change and redistribute it.\n"
              "There is NO WARRANTY, to the extent permitted by law.\n"
